# pynrl1

L1 5G NR 3GPP Python implementation.

# Installation

You need Python 3.9+ and some additional math packages like numpy and so on.

## pypi

```python
pip install pynrl1
```

## Sources

```python
git clone https://github.com/vborchsh/pynrl1
cd pynrl1
pip install .
```

# Testing

At the moment, most part of code covered by MATLAB + pytest.

# Limitations

1. The only anthenna port assumed
2. Any L2 procedures are out of scope

# Contribution

[TODO list](https://github.com/vborchsh/pynrl1/blob/master/TODO.md)

Nothing exceptional: fork -> edit -> pull request

